<template>
  <div class="all">
    <div class="cluster-content">
      <div class="cluster-center" ref="left">
        <div
          class="menu-item"
          v-for="(item, i) in tabList"
          :key="i"
          @click="openRight(item, i)"
          ref="leftbar"
        >
          <div>{{ item.name }}</div>
        </div>
      </div>
      <div class="cluster-right">
        <div class="lang" v-if="activePage == '系统语言'">
          <div class="title">语言列表</div>
          <div
            class="bar"
            v-for="(item, i) in langList"
            :key="i"
            @click="pickLang(item, i)"
          >
            <span class="name">{{ item.Name }}</span>
            <span class="icon iconfont" v-show="activeLang == item.Lang"
              >已选</span
            >
          </div>
        </div>
        <div class="lang" v-if="activePage == '键盘管理'">
          <div class="title">键盘布局</div>
          <div
            class="bar"
            v-for="(item, i) in keyboardList"
            :key="i"
            @click="pickKb(item, i)"
          >
            <span class="name">{{ item.name }}</span>
            <span class="icon iconfont" v-show="activeKb == item.id">已选</span>
            <!-- <span class="icon iconfont">&#xe646;</span> -->
          </div>
        </div>
      </div>
    </div>
  </div>
</template>

<script>
import {
  createSerfCluster,
  randomPwd,
  search,
  getSearchNodes,
  stopSearching,
  findCluster,
  updateClusterName,
  joinCluster,
  leave,
  getVrrp,
  setVrrp,
  createESNode,
  addESNode,
  getEsClusterInfo,
} from "@/api/clusterManage";

import {
  getLangs,
  setLang,
  getLang,
  getKeyboardLayouts,
  getCurKeyboardLayout,
  setKeyboardLayout,
} from "@/api/system";
import { isIPv4 } from "@/scripts/validate";

export default {
  data() {
    return {
      activeLang: "",
      activeKb: "",
      inWifiDetail: false,
      inWireDetail: false,
      langList: [],
      keyboardList: [],
      tabList: [{ name: "系统语言" }, { name: "键盘管理" }],
      activePage: "系统语言",
      rules: {
        deviceName: [
          { required: true, message: "请输入设备名称", trigger: "change" },
        ],
      },
      value: "",
    };
  },
  mounted() {
    this.fetchLangList();
    this.getCurLang();
    this.fetchKeyBoardList();
    this.getCurKb();
  },
  props: ["barName"],
  methods: {
    getCurKb() {
      getCurKeyboardLayout().then((res) => {
        this.activeKb = res.data.keyboard;
      });
    },

    getCurLang() {
      getLang().then((res) => {
        if (res && res.success) {
          this.activeLang = res.data.lang;
        }
      });
    },
    fetchLangList() {
      getLangs().then((res) => {
        if (res && res.success) {
          this.langList = res.data;
        }
      });
    },
    fetchKeyBoardList() {
      getKeyboardLayouts().then((res) => {
        if (res && res.success) {
          this.keyboardList = res.data.slice(0, 5);
        }
      });
    },
    pickLang(item) {
      setLang({
        lang: item.Lang,
      }).then(
        (res) => {
          this.getCurLang();
          this.$message.success(res.data);
        },
        (err) => {
          this.$message.error(err.msg);
        }
      );
    },
    pickKb(item) {
      setKeyboardLayout({
        layout: item.id,
      }).then(
        (res) => {
          this.getCurKb()
          this.$message.success(res.data);
        },
        (err) => {
          this.$message.error(err.msg);
        }
      );
    },
    openRight(item, i) {
      this.activePage = item.name;
      this.$refs["leftbar"].forEach((x) => {
        x.style.backgroundColor = "rgba(248, 248, 248, 1)";
        x.style.color = "#333";
      });
      this.$refs["leftbar"][i].style.backgroundColor = "rgb(61, 104, 225)";
      this.$refs["leftbar"][i].style.color = "white";
    },
    wifiControl(val) {},
    checkWifi() {
      this.inWifiDetail = true;
    },
    checkWire(item) {
      this.inWireDetail = true;
    },
  },
};
</script>
<style lang="scss">
.all {
  width: 100%;
}

.cluster-content {
  height: 100%;
  display: flex;
  flex-direction: row;
  flex: 1;
  flex-basis: auto;
  box-sizing: border-box;
  .cluster-center {
    height: 100%;
    width: 280px;
    overflow: auto;
    box-sizing: border-box;
    flex-shrink: 0;
    padding: 10px;
    border-right: 5px solid #f8f8f8;

    // background-color: lavender;
    .menu-item {
      background-color: #f8f8f8;
      height: 40px;
      margin-bottom: 10px;
      border-radius: 8px;
      line-height: 40px;
      box-sizing: border-box;
      font-size: 14px;
      padding: 0 20px;
      display: flex;
      justify-content: space-between;
    }
  }
  .cluster-right {
    flex: 1;
    flex-basis: auto;
    overflow: auto;
    // background-color: rgba(240, 242, 245, 1);
    box-sizing: border-box;
    position: relative;
    padding: 20px 40px;
    // .create-new .join-exist {
    .el-form-item.is-required:not(.is-no-asterisk)
      > .el-form-item__label:before,
    .el-form-item.is-required:not(.is-no-asterisk)
      .el-form-item__label-wrap
      > .el-form-item__label:before {
      display: none;
    }
    .el-select {
      width: 100%;
    }
    .el-form-item {
      margin-bottom: 10px;
      height: 50px;
      background: #f8f8f8;
      padding: 4px 20px;
      -webkit-box-sizing: border-box;
      box-sizing: border-box;
      border-radius: 10px;
      .el-form-item__label {
        text-align: left;
        line-height: 42px;
      }
    }
    .el-form-item__content {
      line-height: 40px;
      position: relative;
      font-size: 14px;
    }
    .ip-input-container {
      max-width: none !important;
    }
    .lang {
      .bar {
        height: 50px;
        background-color: aliceblue;
        border-radius: 10px;
        line-height: 50px;
        box-sizing: border-box;
        padding: 0 20px;
        display: flex;
        justify-content: space-between;
        margin-bottom: 10px;
      }
    }
    .save-btn {
      background-color: #3d68e1;
      width: 240px;
      height: 40px;
      margin: 0 auto;
      border-radius: 10px;
      color: #fff;
      line-height: 40px;
      font-size: 14px;
      margin-top: 20px;
    }
  }
}
</style>
